/**
 * Copyright (C) 2008  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.console.security;

import org.exoplatform.container.PortalContainer;

/**
 * Security configuration allow to set the default configuration to the
 * security. It is used to set the different profiles, to associated them to
 * user membership and group couple, and give permissions to those profiles.
 * 
 * TODO : the security configuration will be setted after with a configuration
 * file or/and with a portlet.
 * 
 * @author Elwalid Brahim <elwalid.brahim@bull.net>
 */

public class SecurityConfiguration {

  /** Contructor **/
  public SecurityConfiguration() {
  }

  /**
   * Set the default configuration
   */
  public void setDefaultConfiguration() {
    PortalContainer portalContainer = PortalContainer.getInstance();
    SecurityService securityService = (SecurityService) portalContainer.getComponentInstanceOfType(SecurityService.class);

    ACLKeyManager keyManager = securityService.getACLKeyManager();
    NovaACL accessList = securityService.getUserACL();
    ProfileManager profileManager = securityService.getProfileManager();

    /*
     * === use the profile manager to associate the couple user
     * memberships/group to a profiles ===
     */
    /* format : "membership:group" */

    /* Orchestra */
    /* example for the administrator profile */
    // profileManager.addProfile("administrator:/console/orchestra",
    // "orchestra.administrator.engine");
    profileManager.addProfile("operator:/platform/console/orchestra", "orchestra.operator.process");

    /* === set the access rights permission for each profile === */

    /* Orchestra */
    // TODO : check the deploy permission in the orchestra management portlet
    // accessList.givePermission("orchestra.operator.process",
    // keyManager.generateActionKey("orchestra", "process", "deploy"));
    accessList.givePermission("orchestra.operator.process", keyManager.generateActionKey("orchestra", "process", "undeploy"));

  }
}
